nginx-config-builder
====================

A python library for constructing nginx configuration files.

Contents:

.. toctree::
   :maxdepth: 2

   builder
   block
   common
   helpers

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
